aboutsummaryrefslogtreecommitdiffstatshomepage
path: root/exercises/060_floats.zig
diff options
context:
space:
mode:
Diffstat (limited to 'exercises/060_floats.zig')
-rw-r--r--exercises/060_floats.zig8
1 files changed, 4 insertions, 4 deletions
diff --git a/exercises/060_floats.zig b/exercises/060_floats.zig
index 69b3946..6f341ad 100644
--- a/exercises/060_floats.zig
+++ b/exercises/060_floats.zig
@@ -39,11 +39,11 @@ const print = @import("std").debug.print;
pub fn main() void {
// The approximate weight of the Space Shuttle upon liftoff
- // (including boosters and fuel tank) was 2,200 tons.
+ // (including boosters and fuel tank) was 4,480,000 lb.
//
- // We'll convert this weight from tons to kilograms at a
- // conversion of 907.18kg to the ton.
- const shuttle_weight: f16 = 907.18 * 2200;
+ // We'll convert this weight from pound to kilograms at a
+ // conversion of 0.453592kg to the pound.
+ const shuttle_weight: f16 = 0.453592 * 4480e6;
// By default, float values are formatted in scientific
// notation. Try experimenting with '{d}' and '{d:.3}' to see